<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://www.epubsystems.com
 * @since      1.0.0
 *
 * @package    Epubsystems_woo
 * @subpackage Epubsystems_woo/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Epubsystems_woo
 * @subpackage Epubsystems_woo/includes
 * @author     Nir Louk <looknear@gmail.com>
 */
class Epubsystems_woo {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Epubsystems_woo_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'EPUBSYSTEMS_WOO_PLUGIN_NAME_VERSION' ) ) {
			$this->version = EPUBSYSTEMS_WOO_PLUGIN_NAME_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'epubsystems_woo';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Epubsystems_woo_Loader. Orchestrates the hooks of the plugin.
	 * - Epubsystems_woo_i18n. Defines internationalization functionality.
	 * - Epubsystems_woo_Admin. Defines all hooks for the admin area.
	 * - Epubsystems_woo_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-epubsystems_woo-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-epubsystems_woo-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-epubsystems_woo-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-epubsystems_woo-public.php';

		$this->loader = new Epubsystems_woo_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Epubsystems_woo_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Epubsystems_woo_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Epubsystems_woo_Admin( $this->get_plugin_name(), $this->get_version() );

		// Save/Update our plugin options
		$this->loader->add_action('admin_init', $plugin_admin, 'options_update');
		//make admin menu
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_plugin_admin_menu' );

		//register js and css
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		//show the es_user_email to admin on order page
		//also in list of orders
		$this->loader->add_action( 'woocommerce_admin_order_data_after_shipping_address', $plugin_admin, 'admin_show_order_meta' );

                //hook into ADMIN creating an order
		$this->loader->add_action( 'woocommerce_process_shop_order_meta', $plugin_admin, 'admin_update_order_meta', 10, 2 );

		//add webhook status columns to order list - title and data
		$this->loader->add_filter( 'manage_edit-shop_order_columns', $plugin_admin, 'admin_add_orders_columns_title', 10, 1 );
		$this->loader->add_action( 'manage_shop_order_posts_custom_column', $plugin_admin, 'admin_set_orders_columns_data', 10, 2 );

		//hook on recieving the webhook data
		$this->loader->add_action( 'woocommerce_webhook_delivery', $plugin_admin, 'es_get_webhook_response', 1, 5 );
		//temp disable async
		//$this->loader->add_filter( 'woocommerce_webhook_deliver_async', $plugin_public, 'es_disable_async_webhook', 10, 0 );
	
		//add "eBook" simple product option
		$this->loader->add_filter( 'product_type_options', $plugin_admin, 'admin_add_es_ebook_simple_product_option', 10, 1 );
		$this->loader->add_action( 'woocommerce_admin_process_product_object', $plugin_admin, 'es_save_simple_product_option', 10, 1 );
		//add custom fields to simple product general tab
		$this->loader->add_action( 'woocommerce_product_options_general_product_data', $plugin_admin,'es_add_simple_product_custom_fields', 10, 0 );
		
		//add "eBook" to variation
		$this->loader->add_action( 'woocommerce_variation_options', $plugin_admin, 'admin_add_es_ebook_variation_product_option', 10, 3 );
		//add custom fields to variation
		$this->loader->add_action( 'woocommerce_variation_options', $plugin_admin,'es_add_variation_custom_fields', 10, 3 );
		$this->loader->add_action( 'woocommerce_save_product_variation', $plugin_admin, 'es_save_variation_product_option', 10, 1 );

		//ajax end point for convert too actions
		$this->loader->add_action( 'wp_ajax_es_woo_sell_ajax_endpoint', $plugin_admin, 'es_woo_sell_ajax_endpoint' );
		$this->loader->add_action( 'admin_action_modal_convert_to_ebook', $plugin_admin, 'open_thickbox_modal_convert_to_ebook' );
		$this->loader->add_action( 'admin_action_modal_copy_sku_to_ebook_code', $plugin_admin, 'open_thickbox_modal_copy_sku_to_ebook_code' );
                
                
                
                
                
        }

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	 //https://businessbloomer.com/woocommerce-visual-hook-guide-checkout-page/
	private function define_public_hooks() {

		$plugin_public = new Epubsystems_woo_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

		//add fields to woo order
		$this->loader->add_action( 'woocommerce_checkout_update_order_meta', $plugin_public, 'checkout_update_order_meta' );
		//add fields to item line
		$this->loader->add_action( 'woocommerce_checkout_create_order_line_item', $plugin_public, 'adding_custom_data_in_order_items_meta', 1, 4 );

		//hide it from ADMIN order display
		//$this->loader->add_action( 'woocommerce_hidden_order_itemmeta', $plugin_public, 'remove_order_item_meta_fields' );
		$this->loader->add_action('woocommerce_order_item_get_formatted_meta_data', $plugin_public, 'filter_format_order_meta_data');

		//show es_user_email to user on order before pay - so he can change it as gift
		$this->loader->add_action( 'woocommerce_after_order_notes', $plugin_public, 'customise_checkout_field' );
		//check the checkout form for errors
		$this->loader->add_action('woocommerce_checkout_process', $plugin_public, 'customise_checkout_field_process');


	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Epubsystems_woo_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
